@@ -63,7 +63,7 @@ Jeff Anderson, C<< <jeffa at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016 Jeff Anderson.
+Copyright 2017 Jeff Anderson.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
@@ -108,12 +108,13 @@ __DATA__
 720p
 1080p
 mp4
+mp3
 avi
 mkv
-srt
-idx
-sub
 bluray
+brrip
+webrip
+xvid
 dvd
 h264
 aac
